@@ -1,16 +1,18 @@
-#' Lookup article info via CrossRef with DOI and get a citation count.
+#' Get a citation count via CrossRef OpenURL
 #'
 #' @export
 #'
-#' @param doi digital object identifier for an article in PLoS Journals
-#' @param url the PLoS API url for the function (should be left to default)
-#' @param key your PLoS API key, either enter, or loads from .Rprofile
-#' @param ... Named parameters passed on to \code{\link[httr]{GET}}
+#' @param doi (character) digital object identifier for an article
+#' @param url (character) the url for the function (should be left to default)
+#' @param key your Crossref OpenURL email address, either enter, or loads 
+#' from \code{.Rprofile}. We use a default, so you don't need to pass this.
+#' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #'
-#' @return citation count
+#' @return single numeric value - the citation count, or NA if not found or
+#' no count available
 #' @details See \url{http://labs.crossref.org/openurl/} for more info on this
 #' 		Crossref API service.
-#' @seealso \code{\link{cr_search}}, \code{\link{cr_r}}, \code{\link{cr_search_free}}
+#' @seealso \code{\link{cr_search}}, \code{\link{cr_r}}
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
 #' @examples \dontrun{
 #' cr_citation_count(doi="10.1371/journal.pone.0042793")
@@ -20,9 +22,8 @@
 #' }
 
 cr_citation_count <- function(doi, url = "http://www.crossref.org/openurl/",
-	key = "cboettig@ropensci.org", ...)
-{
-  ## Assemble a url query such as:
+	key = "cboettig@ropensci.org", ...) {
+  
   args <- list(id = paste("doi:", doi, sep = ""), pid = as.character(key),
                noredirect = as.logical(TRUE))
   cite_count <- GET(url, query = args, make_rcrossref_ua(), ...)
