@@ -43,7 +43,7 @@
                           sort = sort, order = order))
 
   tmp <- licenses_GET(args = args, parse = TRUE, ...)
-  df <- rbind_all(lapply(tmp$message$items, data.frame, stringsAsFactors = FALSE))
+  df <- tbl_df(bind_rows(lapply(tmp$message$items, data.frame, stringsAsFactors = FALSE)))
   meta <- parse_meta(tmp)
   list(meta = meta, data = df)
 }
