@@ -16,8 +16,8 @@
 #' cr_r()
 #' }
 
-`cr_r` <- function(sample = 10, ...)
-{
-  tmp <- cr_works(sample=sample, ...)
-  tmp$data$DOI
+`cr_r` <- function(sample = 10, ...) {
+  tmp <- cr_works(sample = sample, ...)
+  dois <- suppressWarnings(tryCatch(tmp$data$DOI, error = function(e) e))
+  if (inherits(dois, "error")) NULL else dois
 }
